@@ -1,4 +1,4 @@
-package Pcore::PDF v0.3.4;
+package Pcore::PDF v0.3.5;
 
 use Pcore -dist, -class, -const, -result;
 use Config;
@@ -375,8 +375,8 @@ sub _run_task ( $self, $proc, $task ) {
 ## |======+======================+================================================================================================================|
 ## |    2 |                      | Documentation::RequirePodLinksIncludeText                                                                      |
 ## |      | 384                  | * Link L<Pcore::Util::Result> on line 441 does not specify text                                                |
-## |      | 384                  | * Link L<Pcore::Util::Result> on line 448 does not specify text                                                |
-## |      | 384                  | * Link L<Pcore> on line 447 does not specify text                                                              |
+## |      | 384                  | * Link L<Pcore::Util::Result> on line 451 does not specify text                                                |
+## |      | 384                  | * Link L<Pcore> on line 449 does not specify text                                                              |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
@@ -444,9 +444,15 @@ Generates PDF from C<< $html >> template. Call C<< $cb->($result) >> on finish,
 
 =head1 SEE ALSO
 
-L<Pcore>
-L<Pcore::Util::Result>
-L<https://www.princexml.com/|https://www.princexml.com/>
+=over
+
+=item L<Pcore>
+
+=item L<Pcore::Util::Result>
+
+=item L<https://www.princexml.com/|https://www.princexml.com/>
+
+=back
 
 =head1 AUTHOR
 
